==> nextcloud-app-bookmarks-1%3A4.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/bookmarks/l10n/he.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "סימניות",
    "No file provided for import" : "לא סופק קובץ לייבוא",
    "Unsupported file type for import" : "סוג הקובץ לייבוא אינו נתמך",
    "Bookmarks shared by %s" : "סימניות שמשותפות על ידי %s",
    "Recent Bookmarks" : "סימניות אחרונות",
    "A Bookmark manager for Nextcloud" : "מנהל סימניות ל־Nextcloud",
    "Select bookmark" : "בחירת סימנייה",
    "Details" : "פרטים",
    "Rename" : "שינוי שם",
    "Move" : "העברה",
    "Delete" : "מחיקה",
    "Search" : "חיפוש",
    "Select one or more tags" : "יש לבחור תגית אחת או יותר",
    "New" : "חדש",
    "New bookmark" : "סימנייה חדשה",
    "New folder" : "תיקייה חדשה",
    "Grid view" : "תצוגת טבלה",
    "List view" : "תצוגת רשימה",
    "Move selection" : "העברת בחירה",
    "Delete selection" : "מחיקת בחירה",
    "Open all selected" : "לפתוח את כל הנבחרים",
    "Select all" : "בחר הכל",
    "Cancel selection" : "ביטול בחירה",
    "Selected {folders} folders and {bookmarks} bookmarks" : "נבחרו {folders} תיקיות ו־{bookmarks} סימניות",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["סימנייה אחת נבחרה","%n סימניות נבחרו","%n סימניות נבחרו","%n סימניות נבחרו"],
    "_Selected %n folder_::_Selected %n folders_" : ["נבחרה תיקייה %n","נבחרו %n תיקיות","נבחרו %n תיקיות","נבחרו %n תיקיות"],
    "Enter a link" : "נא למלא קישור",
    "Select folder" : "בחירת תיקייה",
    "Enter folder title" : "נא למלא כותרת לתיקייה",
    "Shared by {user}" : "שותפה על ידי {user}",
    "Root folder" : "תיקיית בסיס",
    "Submit" : "שליחה",
    "Cancel" : "ביטול",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["תיקייה אחת ומספר סימניות מועברות","%n תיקיות ומספר סימניות מועברות","%n תיקיות ומספר סימניות מועברות","%n תיקיות ומספר סימניות מועברות"],
    "_Moving %n folder_::_Moving %n folders_" : ["תיקייה אחת מועברת","%n תיקיות מועברות","%n תיקיות מועברות","%n תיקיות מועברות"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["סימנייה אחת מועברת","%n סימניות מועברות","%n סימניות מועברות","%n סימניות מועברות"],
    "All bookmarks" : "כל הסימניות",
    "Recent" : "אחרונים",
    "Untagged" : "ללא תגית",
    "{used} bookmarks of {available} available" : "{used} סימניות מתוך {available} זמינות",
    "No bookmarks here" : "אין כאן סימניות",
    "Add a bookmark" : "הוספת סימנייה",
    "Import" : "ייבוא",
    "Export" : "ייצוא",
    "Sorting" : "מיון",
    "Recently added" : "נוספו לאחרונה",
    "Alphabetically" : "בסדר האלף-בית",
    "Most visited" : "הכי הרבה ביקורים",
    "Last modified" : "מועד שינוי אחרון",
    "Client apps" : "יישומוני לקוח",
    "Also check out the collection of client apps that integrate with this app: " : "כדאי להציץ באוסף יישומוני הלקוח שמשתלבים עם היישומון הזה:",
    "Bookmarklet" : "יישומון סימנייה",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage" : "יש לגרור זאת לדפדפן שלך וללחוץ על זה כדי להוסיף דף כלשהו כסימנייה",
    "Add to {instanceName}" : "הוספה אל {instanceName}",
    "Clear data" : "ניקוי מידע",
    "Delete all bookmarks" : "מחיקת כל הסימניות",
    "Do you really want to delete all your bookmarks?" : "למחוק את כל הסימניות שלך?",
    "Title" : "תפקיד",
    "Link" : "קישור",
    "Creation date" : "מועד יצירה",
    "Tags" : "תגיות",
    "Attachments" : "קבצים מצורפים",
    "Notes" : "הערות",
    "{time} ago" : "לפני {time}",
    "Owner" : "בעלות",
    "Sharing" : "שיתוף",
    "Select a user or group" : "נא לבחור משתמש או קבוצה",
    "Share link" : "קישור שיתוף",
    "Copy link" : "העתקת קישור",
    "Delete link" : "מחיקת קישור",
    "Create public link" : "יצירת קישור ציבורי",
    "Allow editing" : "לאפשר עריכה",
    "Allow sharing" : "לאפשר שיתוף",
    "Remove share" : "הסרת שיתוף",
    "Link copied" : "הקישור הועתק",
    "Select" : "בחירה",
    "Previews" : "תצוגות מקדימות",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "ניתן להירשם בחינם בכתובת screeenly.com או להקים שרת משלך.",
    "Screeenly API URL" : "כתובת ה־API של Screeenly",
    "Screeenly API key" : "מפתח ה־API של Screeenly",
    "Privacy" : "פרטיות",
    "Bookmarks will try to access web pages that you add to automatically add information about them." : "תכנית הסימניות תנסה לגשת אל האתרים שהוספת כדי להוסיף עליהן מידע אוטומטית.",
    "Enable accessing and collecting information from the web pages you add" : "הפעלת גישה ואיסוף של מידע מהאתרים שהוספת.",
    "Performance" : "ביצועים",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "כמות הסימניות המרבית לחשבון. (0 ללא הגבלה וזאת גם בררת המחדל)",
    "Failed to load settings" : "טעינת ההגדרות נכשלה",
    "Failed to save settings" : "שמירת ההגדרות נכשלה",
    "This URL is already bookmarked! Overwrite?" : "כתובת זו כבר נשמרה בסימניות! לשכתב?",
    "Enter bookmark title" : "נא להקליד כותרת לסימנייה",
    "Enter bookmark URL" : "נא למלא כתובת סימנייה",
    "Folder" : "תיקייה",
    "Save" : "שמירה",
    "Failed to find existing bookmark" : "איתור סימנייה קיימת נכשל",
    "Failed to create bookmark" : "יצירת סימנייה נכשלה",
    "Failed to save bookmark" : "שמירת סימנייה נכשלה",
    "Failed to move bookmark" : "העברת סימנייה נכשלה",
    "Failed to delete bookmark" : "מחיקת הסימנייה נכשלה",
    "Failed to load tags" : "טעינת התגיות נכשלה",
    "Failed to load folders" : "טעינת התיקיות נכשלה",
    "Failed to delete folder" : "מחיקת התיקייה נכשלה",
    "Failed to create folder" : "יצירת התיקייה נכשלה",
    "Failed to fetch bookmarks." : "קבלת הסימניות נכשלה.",
    "Failed to change setting" : "שינוי ההגדרות נכשל",
    "Failed to load setting {key}" : "טעינת ההגדרה {key} נכשלה",
    "Failed to update share {shareId}" : "עדכון השיתוף {shareId} נכשל",
    "Failed to delete share {shareId}" : "מחיקת השיתוף {shareId} נכשלה",
    "Bookmarks feed" : "ערוץ סימניות"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");

==> nextcloud-app-bookmarks-1%3A4.0.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/bookmarks/l10n/he.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "סימניות",
    "You bookmarked \"%s\"" : "הוספת את „%s” לסימניות",
    "%1$s bookmarked \"%2$s\"" : "„%2$s” התווסף לסימניות על ידי %1$s",
    "Someone bookmarked \"%s\"" : "מישהו הוסיף את „%s” לסימניות",
    "You deleted \"%s\"" : "מחקת את „%s”",
    "%1$s deleted \"%2$s\"" : "„%2$s” נמחק על ידי %1$s",
    "Someone deleted \"%s\"" : "מישהו מחק את „%s”",
    "You created folder \"%s\"" : "יצרת את התיקייה „%s”",
    "You moved folder \"%s\"" : "העברת את התיקייה „%s”",
    "No file provided for import" : "לא סופק קובץ לייבוא",
    "Unsupported file type for import" : "סוג הקובץ לייבוא אינו נתמך",
    "Bookmarks shared by %s" : "סימניות שמשותפות על ידי %s",
    "Recent Bookmarks" : "סימניות אחרונות",
    "A Bookmark manager for Nextcloud" : "מנהל סימניות ל־Nextcloud",
    "Select bookmark" : "בחירת סימנייה",
    "Details" : "פרטים",
    "Rename" : "שינוי שם",
    "Move" : "העברה",
    "Delete" : "מחיקה",
    "Search" : "חיפוש",
    "Select one or more tags" : "יש לבחור תגית אחת או יותר",
    "New" : "חדש",
    "New bookmark" : "סימנייה חדשה",
    "New folder" : "תיקייה חדשה",
    "Grid view" : "תצוגת טבלה",
    "List view" : "תצוגת רשימה",
    "Move selection" : "העברת בחירה",
    "Delete selection" : "מחיקת בחירה",
    "Open all selected" : "לפתוח את כל הנבחרים",
    "Select all" : "בחר הכל",
    "Cancel selection" : "ביטול בחירה",
    "Selected {folders} folders and {bookmarks} bookmarks" : "נבחרו {folders} תיקיות ו־{bookmarks} סימניות",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["סימנייה אחת נבחרה","%n סימניות נבחרו","%n סימניות נבחרו","%n סימניות נבחרו"],
    "_Selected %n folder_::_Selected %n folders_" : ["נבחרה תיקייה %n","נבחרו %n תיקיות","נבחרו %n תיקיות","נבחרו %n תיקיות"],
    "Enter a link" : "נא למלא קישור",
    "Select folder" : "בחירת תיקייה",
    "Enter folder title" : "נא למלא כותרת לתיקייה",
    "Shared by {user}" : "שותפה על ידי {user}",
    "Root folder" : "תיקיית בסיס",
    "Submit" : "שליחה",
    "Cancel" : "ביטול",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["תיקייה אחת ומספר סימניות מועברות","%n תיקיות ומספר סימניות מועברות","%n תיקיות ומספר סימניות מועברות","%n תיקיות ומספר סימניות מועברות"],
    "_Moving %n folder_::_Moving %n folders_" : ["תיקייה אחת מועברת","%n תיקיות מועברות","%n תיקיות מועברות","%n תיקיות מועברות"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["סימנייה אחת מועברת","%n סימניות מועברות","%n סימניות מועברות","%n סימניות מועברות"],
    "All bookmarks" : "כל הסימניות",
    "Recent" : "אחרונים",
    "Untagged" : "ללא תגית",
    "{used} bookmarks of {available} available" : "{used} סימניות מתוך {available} זמינות",
    "No bookmarks here" : "אין כאן סימניות",
    "Add a bookmark" : "הוספת סימנייה",
    "Import" : "ייבוא",
    "Export" : "ייצוא",
    "Sorting" : "מיון",
    "Recently added" : "נוספו לאחרונה",
    "Alphabetically" : "בסדר האלף-בית",
    "Most visited" : "הכי הרבה ביקורים",
    "Last modified" : "מועד שינוי אחרון",
    "Client apps" : "יישומוני לקוח",
    "Also check out the collection of client apps that integrate with this app: " : "כדאי להציץ באוסף יישומוני הלקוח שמשתלבים עם היישומון הזה:",
    "Install web app" : "התקנת יישומון דפדפן",
    "Install on home screen" : "התקנה על מסך הבית",
    "Bookmarklet" : "יישומון סימנייה",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage" : "יש לגרור זאת לדפדפן שלך וללחוץ על זה כדי להוסיף דף כלשהו כסימנייה",
    "Add to {instanceName}" : "הוספה אל {instanceName}",
    "Clear data" : "ניקוי מידע",
    "Permanently remove all bookmarks from your account." : "הסרת כל הסימניות מהחשבון שלך לצמיתות.",
    "Delete all bookmarks" : "מחיקת כל הסימניות",
    "Do you really want to delete all your bookmarks?" : "למחוק את כל הסימניות שלך?",
    "Title" : "תפקיד",
    "Link" : "קישור",
    "Creation date" : "מועד יצירה",
    "Tags" : "תגיות",
    "Attachments" : "קבצים מצורפים",
    "Open archived file" : "פתיחת קובץ שנשמר בארכיון",
    "Notes" : "הערות",
    "{time} ago" : "לפני {time}",
    "Owner" : "בעלות",
    "Sharing" : "שיתוף",
    "Select a user or group" : "נא לבחור משתמש או קבוצה",
    "Share link" : "קישור שיתוף",
    "Copy link" : "העתקת קישור",
    "Delete link" : "מחיקת קישור",
    "Create public link" : "יצירת קישור ציבורי",
    "Allow editing" : "לאפשר עריכה",
    "Allow sharing" : "לאפשר שיתוף",
    "Remove share" : "הסרת שיתוף",
    "Link copied" : "הקישור הועתק",
    "Select" : "בחירה",
    "Previews" : "תצוגות מקדימות",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "ניתן להירשם בחינם בכתובת screeenly.com או להקים שרת משלך.",
    "Screeenly API URL" : "כתובת ה־API של Screeenly",
    "Screeenly API key" : "מפתח ה־API של Screeenly",
    "Privacy" : "פרטיות",
    "Bookmarks will try to access web pages that you add to automatically add information about them." : "תכנית הסימניות תנסה לגשת אל האתרים שהוספת כדי להוסיף עליהן מידע אוטומטית.",
    "Enable accessing and collecting information from the web pages you add" : "הפעלת גישה ואיסוף של מידע מהאתרים שהוספת.",
    "Performance" : "ביצועים",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "כמות הסימניות המרבית לחשבון. (0 ללא הגבלה וזאת גם בררת המחדל)",
    "Failed to load settings" : "טעינת ההגדרות נכשלה",
    "Failed to save settings" : "שמירת ההגדרות נכשלה",
    "This URL is already bookmarked! Overwrite?" : "כתובת זו כבר נשמרה בסימניות! לשכתב?",
    "Enter bookmark title" : "נא להקליד כותרת לסימנייה",
    "Enter bookmark URL" : "נא למלא כתובת סימנייה",
    "Folder" : "תיקייה",
    "Save" : "שמירה",
    "Failed to load bookmark" : "טעינת הסימנייה נכשלה",
    "Failed to find existing bookmark" : "איתור סימנייה קיימת נכשל",
    "Failed to create bookmark" : "יצירת סימנייה נכשלה",
    "Failed to save bookmark" : "שמירת סימנייה נכשלה",
    "Failed to move bookmark" : "העברת סימנייה נכשלה",
    "Failed to delete bookmark" : "מחיקת הסימנייה נכשלה",
    "Failed to rename tag" : "שינוי שם התגית נכשל",
    "Failed to load tags" : "טעינת התגיות נכשלה",
    "Failed to load folders" : "טעינת התיקיות נכשלה",
    "Failed to delete folder" : "מחיקת התיקייה נכשלה",
    "Failed to create folder" : "יצירת התיקייה נכשלה",
    "Failed to fetch bookmarks." : "קבלת הסימניות נכשלה.",
    "Failed to change setting" : "שינוי ההגדרות נכשל",
    "Failed to load setting {key}" : "טעינת ההגדרה {key} נכשלה",
    "Failed to update share {shareId}" : "עדכון השיתוף {shareId} נכשל",
    "Failed to delete share {shareId}" : "מחיקת השיתוף {shareId} נכשלה",
    "Bookmarks feed" : "ערוץ סימניות"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
